==> signet-desktop-client-0.9.8.1.tar.bz2: signet-desktop-client-0.9.8.1/client/searchlistbox.cpp <==
#include "searchlistbox.h"

#include<QLineEdit>
#include<QTreeView>
#include<QListView>
#include<QAbstractItemModel>
#include<QBoxLayout>
#include<QKeyEvent>
#include <QLineEdit>

SearchListbox::SearchListbox(QLineEdit *query_edit, QAbstractItemModel *model, QWidget *parent) : QListView(parent),
	m_queryEdit(query_edit)
{
	setModel(model);
}

void SearchListbox::enableHover()
{
	setMouseTracking(true);
	connect(this, SIGNAL(entered(QModelIndex)), this, SLOT(entered(QModelIndex)));
}

void SearchListbox::disableHover()
{
	setMouseTracking(false);
	disconnect(this, SLOT(entered(QModelIndex)));
}

void SearchListbox::entered(QModelIndex idx)
{
	setCurrentIndex(idx);
	emit selected(idx);
}

void SearchListbox::keyPressEvent(QKeyEvent *event)
{
	int row;
	QModelIndex idx;
	int key = event->key();
	switch (key) {
	case Qt::Key_Backspace:
		if (m_filterText.size() > 0) {
			m_filterText.resize(m_filterText.size() - 1);
			emit filterTextChanged(m_filterText);
		}
		break;
	case Qt::Key_Up:
		row = this->currentIndex().row();
		idx = model()->index(row - 1, 0);
		if (idx.isValid()) {
			this->setCurrentIndex(idx);
			emit selected(idx);
		}
		break;
	case Qt::Key_Down:
		row = this->currentIndex().row();
		idx = model()->index(row + 1, 0);
		if (idx.isValid()) {
			this->setCurrentIndex(idx);
			emit selected(idx);
		}
		break;
	case Qt::Key_Return:
	case Qt::Key_Enter:
		idx = this->currentIndex();
		if (idx.isValid())
			emit activated(idx);
		break;
	default:
		if (event->text().size()) {
			m_filterText.append(event->text());
			emit filterTextChanged(m_filterText);
		}
	}
}

==> signet-desktop-client-0.9.9.tar.bz2: signet-desktop-client-0.9.9/client/searchlistbox.cpp <==
#include "searchlistbox.h"

#include<QLineEdit>
#include<QTreeView>
#include<QListView>
#include<QAbstractItemModel>
#include<QBoxLayout>
#include<QKeyEvent>
#include <QLineEdit>

#include "esdbmodel.h"

SearchListbox::SearchListbox(QLineEdit *query_edit, QAbstractItemModel *model, QWidget *parent) :
	QTreeView(parent),
	m_queryEdit(query_edit)
{
	setIconSize(QSize(24,24));
	setHeaderHidden(true);
	setRootIsDecorated(false);
	setModel(model);
}

void SearchListbox::enableHover()
{
	setMouseTracking(true);
	connect(this, SIGNAL(entered(QModelIndex)), this, SLOT(entered(QModelIndex)));
}

void SearchListbox::disableHover()
{
	setMouseTracking(false);
	disconnect(this, SLOT(entered(QModelIndex)));
}

void SearchListbox::entered(QModelIndex idx)
{
	setCurrentIndex(idx);
	if (model()->rowCount(idx)) {
		setExpanded(idx, true);
	} else {
		emit selected(idx);
	}
}

void SearchListbox::keyPressEvent(QKeyEvent *event)
{
	QModelIndex idx;
	int key = event->key();
	switch (key) {
	case Qt::Key_Backspace:
		if (m_filterText.size() > 0) {
			m_filterText.resize(m_filterText.size() - 1);
			emit filterTextChanged(m_filterText);
		}
		break;
	case Qt::Key_Up:
	case Qt::Key_Down:
		QTreeView::keyPressEvent(event);
		emit selected(currentIndex());
		break;
	case Qt::Key_Return:
	case Qt::Key_Enter: {
		QModelIndex index = currentIndex();
		if (index.isValid()) {
			if (model()->rowCount(index)) {
				setExpanded(index, !isExpanded(index));
			} else {
				emit activated(index);
			}
		}
	} break;
	default:
		if (event->text().size()) {
			m_filterText.append(event->text());
			emit filterTextChanged(m_filterText);
		}
	}
}
